@@ -1,6 +1,3 @@
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Manifest.pm $ $Author: autrijus $
-# $Revision: #18 $ $Change: 1780 $ $DateTime: 2003/10/22 17:13:48 $ vim: expandtab shiftwidth=4
-
 package Module::Install::Admin::Manifest;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
@@ -11,7 +8,7 @@ use Cwd;
 use File::Spec;
 
 # XXX I really want this method in Module::Install::Admin::Makefile
-# But you can't call across Admin modules. Autrijus??
+# But you can't call across Admin modules. Audrey??
 sub dist_preop {
     my ($self, $distdir) = @_;
     return if $self->check_manifest;
@@ -150,8 +147,9 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
-Copyright 2003 by Brian Ingerson E<lt>ingy@cpan.orgE<gt>
+Copyright 2003, 2004 by
+Audrey Tang E<lt>autrijus@autrijus.orgE<gt>,
+Brian Ingerson E<lt>ingy@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
